#include <stdio.h>
#include <rasterfile.h>
#include <pixrect/pixrect.h>
#include <pixrect/pr_io.h>
#include <pixrect/memvar.h>

/* reads a raster file (either standard or compressed) 
   and creates a series of files where .0 is the full resolution 
   and each file that follows is divided by 2  */
/* creates a compressed version of the original as filename.0 
   all put into filename.nxs */
#define MINSIZE 10

char extend[] = ".nxs";

extern Pixrect * mem_create();
struct {
    int   width;
    int   height;
    int   depth;
    int   reserved;
    int xresolution;
    int yresolution;
    char image_name[256];
    char user_data[256];
} image_dat ;

main(argc,argv)
    int argc;
    char *argv[];
{
    Pixrect *image, *d_image;
    FILE *input;
    FILE *output;
    colormap_t colormap;
    int linelen_src,linelen_dst,i;
    int src_x,src_y,dst_x,dst_y,index,namelen=0;
    char fname[90],*cbuf,f2[90];

    if(argc != 2) {
	fprintf(stderr,"Usage requires one filename: fatal error\n");
	exit(5);
    }

    while( fname[namelen] = *argv[1]++ ) namelen++;
    i=0;
    while( f2[i] = fname[i] ) i++;
    input = fopen(fname,"r");
    colormap.type = RMT_NONE;
  
    if(!(image = pr_load(input,&colormap))) {
	fprintf(stderr,"Load failure: File not an image?!\n");
	exit(1);
    }
    if(colormap.type == RMT_EQUAL_RGB) {
	fprintf(stderr,"Color (or grayscale) not handled!\n");
	exit(2);
    }

/* make dir */
    i=0;
    while( fname[namelen+i] = extend[i] ) i++;
    if( mkdir(fname,0777) ) {
	fprintf(stderr,
		"Failure to create temporary directory for images (%s)\n",fname);
	exit(2);
    }
    /* make file in directory */
    namelen += i;
    fname[namelen++] = '/';
    i=0;
    while( fname[namelen+i] = f2[i] ) i++;
    namelen += i;
    d_image = NULL;
    /* write header file */
    fname[namelen] = '.';
    fname[namelen+1]= 'H';
    fname[namelen+2]=0;
    if( fopen ( fname, "r") != NULL ) {
	fprintf(stderr,"file %s already exists!, (please move it)\n",fname);
	exit(5);
    }
    output = fopen(fname,"w");
    image_dat.width = image->pr_size.x;
    image_dat.height = image->pr_size.y;
    image_dat.depth = image->pr_depth;
    image_dat.reserved = 9999;
    image_dat.xresolution = 400;
    image_dat.yresolution = 400;
    /* ascii notes could be inserted here */
    strcpy(image_dat.image_name,f2);
    strcpy(image_dat.user_data,f2);
    cbuf = (char *) &image_dat;
    for(i=0; i < sizeof(image_dat); i++) putc(cbuf[i],output);

    fname[namelen] = '.';
    fname[namelen+1]= '0';
    fname[namelen+2]=0;
    if( fopen ( fname, "r") != NULL ) {
	fprintf(stderr,"file %s already exists!, (please move it)\n",fname);
	exit(5);
    }
    output = fopen(fname,"w");
    if( (pr_dump(image,output,&colormap,2,0)) ) {
	fprintf(stderr,"file NOT written!");
	exit(2);
    }
    fclose(output);
 
    for(index=1;index < 10; index++) {
	src_x=image->pr_size.x;
	src_y=image->pr_size.y;
	dst_x = src_x/2 + 1;
	dst_y = src_y/2 + 1;
	if( dst_x < MINSIZE ) break; 
	d_image = mem_create(dst_x,dst_y,1);
  
	shrink(image,src_y,d_image,1); 
	pr_close(image);
  
	fname[namelen] = '.';
	fname[namelen+1]= '0' + (char) index;
	fname[namelen+2]=0;
	if( fopen ( fname, "r") != NULL ) {
	    fprintf(stderr,"file %s already exists!, (please move it)\n",fname);
	    exit(5);
	}
	output = fopen(fname,"w");
	if( (pr_dump(d_image,output,&colormap,2,0)) ) {
	    fprintf(stderr,"file NOT written!");
	    exit(2);
	}
	fclose(output);
	image = d_image;
    }
    fprintf(stderr,"Image directory created (%s%s)\n",f2,extend);
    exit(0);
}

shrink(src_data,src_height,dst_data,depth)
/* needs the src and dst mem pixs to have been made */
    Pixrect *src_data,*dst_data;
    int src_height,depth;
{
    unsigned char *s_dat, *d_dat, *ptr, *ptr2;
    unsigned char m[16];
    int ld,ls,l,j,n,y;
    unsigned int val;

    if( depth != 1) return;
#ifdef	SUNOS
    /* Assume Sun's SunOS 4.1.x memory pixrect implementation. */
    ls =   mpr_d(src_data)->md_linebytes;
    ld =   mpr_d(dst_data)->md_linebytes;

    s_dat = (unsigned char *) (mpr_d(src_data)->md_image);
    d_dat = (unsigned char *) (mpr_d(dst_data)->md_image);
#else
    /* Assume public domain Solaris raster+pixrect implementation. */
    ls =   mpr_prlinebytes(src_data);
    ld =   mpr_prlinebytes(dst_data);

    s_dat = (unsigned char *) (mpr_primage(src_data));
    d_dat = (unsigned char *) (mpr_primage(dst_data));
#endif
    ptr = s_dat; ptr2 = d_dat;

    /* This algorithm creates a new output image with a factor of 2	*/
    /* compression in each direction.					*/
    /* If the input image is represented by the pixel matrix		*/
    /*	p(0,0), p(0,1) ... p(0,n)					*/
    /*	p(1,0), p(1,1) ... p(1,n)					*/
    /*	...								*/
    /*	p(m,0, p(m,1), ... p(m,n)					*/
    /* Generate a decimated image with pixels d(i,j) where		*/
    /*	d(i,j) = 1 if ( p(2*i+0,2*j+0) + p(2*i+0,2*j+1) +		*/
    /*		        p(i*2+1,j*2+0) + p(i*2+1,j*2+1) >= 2 )		*/
    /* ie the decimated image has pixel (i,j) on if 2 or more of the	*/
    /* pixels in the corresponding 2x2 input pixel matrix were on.	*/

    m[0] = 128;
    for(j=6; j>=0; j--) m[7-j] = m[6-j]/2;

    for(y = 0; y < (src_height-1) ; y+=2 ) {
	s_dat = ptr + y * ls;
	d_dat = ptr2 + (y/2)* ld;
	for(n=0;n<(ls-1);n+=2) {
	    *d_dat = 0;
	    for(j=0;j<4;j++) {
		l = 2*j;
		val=  (  (*s_dat&m[l])     >>1)
		    +( (*s_dat&m[l+1])       )
		    +( (*(s_dat+ls) &m[l])>>1)
		    +((*(s_dat+ls)&m[l+1])   );
		if( val >=  m[l] ) *d_dat += m[j] ;
	    }
	    s_dat++;
	    for(j=0;j<4;j++) {
		l = 2*j;
		val=  (  (*s_dat&m[l])     >>1)
		    +( (*s_dat&m[l+1])       )
		    +( (*(s_dat+ls) &m[l])>>1)
		    +((*(s_dat+ls)&m[l+1])   );
		if( val >=  m[l] ) *d_dat += m[j+4] ; 
	    }
	    s_dat++;
	    d_dat++;
	}
    }
}
