#include <stdio.h>
/* see setbit() for note on error in logic of routine */
#include <pixrect/pixrect.h>
#include <pixrect/pr_io.h>
#include <rasterfile.h>

extern Pixrect * mem_create();

main(argc,argv)
int argc;
char *argv[];
{
Pixrect *image, *d_image, *shrink();
FILE *input = stdin;
FILE *output = stdout;
colormap_t colormap;
int i;
float xf=1.,yf=1.;
double atof();

for(i=1; i< argc; i++) {
   if( *argv[i] != '-' ) {
      fprintf(stderr,"usage requires scaling factors preceded by '-': (factor %d)\n",i);
      exit(3);
      }
   if( *(argv[i]+1) == 'x' ) xf = atof( argv[i]+2 );
   if( *(argv[i]+1) == 'y' ) yf = atof( argv[i]+2 );
   }

colormap.type = RMT_NONE;

if( !(image = pr_load(input,&colormap)))
	exit(1);

if(colormap.type == RMT_EQUAL_RGB)
	exit(2);

d_image = shrink(image,xf,yf); 
if ( pr_dump(d_image,output,colormap,RT_BYTE_ENCODED,0))
    fprintf(stderr,"shrink: failed\n");
exit(0);
}

Pixrect *shrink(pr_src,xf,yf)
Pixrect *pr_src;
float xf,yf;
{
Pixrect *pr_dst;
int Dx,Dy;
float w,h;
int i,j,val;

/* xf is the scaling factor in x
   yf is hte scaling factor in y */

Dx = (int) ((float) pr_src->pr_size.x) * xf;
Dy = (int) ((float) pr_src->pr_size.y) * yf;

pr_dst = mem_create( Dx,Dy,1 );

w= 1./xf;  /* w,h here are the size of hte source region that compresses
	      into a dst pixel */
h= 1./yf;

for( i=0; i<Dy; i++)
   for( j=0; j<Dx; j++) {
      val = setbit(pr_src, j/xf,i/yf,w,h); 
      pr_put(pr_dst,j,i,val);
      }

return( pr_dst );
}

setbit(pr_src, x,y, w,h)
/* note there is a logical error here; the averaging near the boundaries
   includes src pixels outside the src pixrecxt! thus hte image is degraded
   near the boundaries (since get_pixel is used there is no fatal error
   given  */
Pixrect *pr_src;
float x,y,w,h;
{
int i0,iN,j0,jN;
int i,j,set;
float fj0,fjN,fi0,fiN;
float area,b,bit;

area = 0.;
bit  = 0.;

area = w*h;
i0 = (int) (y - h/2.); /* i0,j0 etc are the pixels in the src that are at */
iN = (int) (y + h/2.); /* at the corners of the averaging region */
j0 = (int) (x - w/2.);
jN = (int) (x + w/2.);

fi0 = (float) (i0+1) - (y - h/2.); /* the marginal amount of the bounding */
fiN = y + h/2. - (float) iN;       /* pixels to weigh in the average */
fj0 = (float) (j0+1) - (x - w/2.);
fjN = x + w/2. - (float) jN;

for( i=i0; i<=iN; i++) { /* sum over the src contributing region */
   for( j=j0; j<= jN; j++) {
      b = (float) pr_get(pr_src,j,i);
      if( j==j0 ) b*= fj0;  /* weight the boundaries */
      if( j==jN ) b*= fjN;
      if( i==i0 ) b*= fi0;
      if( i==iN ) b*= fiN;
      bit += b;
      }
   }

if( bit/area > .5) set = 1;
else    set = 0;

return(set);
}


