
#include <stdio.h>
#include <sys/param.h>
#include <sys/types.h>
#include <xview/xview.h>
#include <xview/canvas.h>
#include <xview/panel.h>
#include <xview/scrollbar.h>
#include <xview/svrimage.h>
#include <xview/termsw.h>
#include <xview/text.h>
#include <xview/tty.h>
#include <xview/xv_xrect.h>
#include "load_choser.h"
#include "SAC.h"

extern Attr_attribute	INSTANCE;

/*
 * Initialize load module.
 */
void
load_initialize(owner)
        Xv_opaque       owner;
{
        extern char    *getwd();

	Load_choser = load_choser_objects_initialize(NULL, owner);
        load_dir_set(getwd(loadpath));
        load_file_set("");
	xv_set(Load_choser->dpi, PANEL_VALUE, "0", 0);
}

/*
 * Initialize save module.
 */
void
save_initialize(owner)
        Xv_opaque       owner;
{
        extern char    *getwd();

	Save_choser = save_choser_objects_initialize(NULL, owner);
        save_dir_set(getwd(savepath));
        save_file_set("");
}

/*
 * Initialize SAC module.
 */
void
SAC_initialize(owner)
        Xv_opaque       owner;
{
        extern char    *getwd();
	extern struct SAChead SAC_head;
	struct SAChead2 *SAC_ptr;
	int i;

        Save_SAC = save_SAC_objects_initialize(NULL, owner);
        SAC_dir_set(getwd(savepath));
        SAC_file_set("");
	xv_set(Save_SAC->kstnm, PANEL_VALUE, "station name", 0);
	xv_set(Save_SAC->B, PANEL_VALUE, "0", 0);
	xv_set(Save_SAC->delta, PANEL_VALUE, "1", 0);
	xv_set(Save_SAC->nzyear, PANEL_VALUE, "0", 0);
	xv_set(Save_SAC->nzday, PANEL_VALUE, "0", 0);
	xv_set(Save_SAC->nzhour, PANEL_VALUE, "0", 0);
	xv_set(Save_SAC->nzmin, PANEL_VALUE, "0", 0);
	xv_set(Save_SAC->nzsec, PANEL_VALUE, "0", 0);
	xv_set(Save_SAC->nzmsec, PANEL_VALUE, "0", 0);
        xv_set(Save_SAC->pix_dif, PANEL_VALUE, "1", 0); 
        xv_set(Save_SAC->time_dif, PANEL_VALUE, "1", 0);
/* initialize SAC header to NULL */
	SAC_ptr = (struct SAChead2 *) &SAC_head.delta;
	for(i = 0 ; i < NUM_FLOAT ; i++ ) SAC_ptr->SACfloat[i] = -12345.;
	for(i = 0 ; i < MAXINT ; i++ ) SAC_ptr->SACint[i] = -12345;
}



load_choser_objects *
load_choser_objects_initialize(ip, owner)
	load_choser_objects	*ip;
	Xv_opaque	owner;
{
	if (!ip && !(ip = (load_choser_objects *) calloc(1, sizeof (load_choser_objects))))
		return (load_choser_objects *) NULL;
	if (!ip->load_popup)
		ip->load_popup = load_choser_load_popup_create(ip, owner);
	if (!ip->controls)
		ip->controls = load_choser_controls_create(ip, ip->load_popup);
	if (!ip->directory)
		ip->directory = load_choser_directory_create(ip, ip->controls);
	if (!ip->file)
		ip->file = load_choser_file_create(ip, ip->controls);
	if (!ip->dpi)
		ip->dpi = load_choser_dpi_create(ip, ip->controls);
	if (!ip->message1)
		ip->message1 = load_choser_message1_create(ip, ip->controls);
	if (!ip->load_but)
		ip->load_but = load_choser_load_but_create(ip, ip->controls);
	return ip;
}

/*
 * Create object `load_popup' in the specified instance.
 */
Xv_opaque
load_choser_load_popup_create(ip, owner)
	load_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, FRAME_CMD,
		XV_KEY_DATA, INSTANCE, ip,
		XV_WIDTH, 799,
		XV_HEIGHT, 112,
		XV_LABEL, "Load file",
		FRAME_SHOW_FOOTER, TRUE,
		FRAME_SHOW_RESIZE_CORNER, TRUE,
		FRAME_CMD_PUSHPIN_IN, FALSE,
		NULL);
	xv_set(xv_get(obj, FRAME_CMD_PANEL), WIN_SHOW, FALSE, NULL);
	return obj;
}

/*
 * Create object `controls' in the specified instance.
 */
Xv_opaque
load_choser_controls_create(ip, owner)
	load_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 0,
		XV_Y, 0,
		XV_WIDTH, WIN_EXTEND_TO_EDGE,
		XV_HEIGHT, WIN_EXTEND_TO_EDGE,
		WIN_BORDER, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `directory' in the specified instance.
 */
Xv_opaque
load_choser_directory_create(ip, owner)
	load_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 10,
		PANEL_VALUE_DISPLAY_LENGTH, 60,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "Directory:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `dpi' in the specified instance.
 */
Xv_opaque
load_choser_dpi_create(ip, owner)
	load_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 32,
		XV_Y, 80,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "Enter DPI (default is value in .H file):",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `file' in the specified instance.
 */
Xv_opaque
load_choser_file_create(ip, owner)
	load_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 32,
		XV_Y, 32,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "Name:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `message1' in the specified instance.
 */
Xv_opaque
load_choser_message1_create(ip, owner)
	load_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_MESSAGE,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 16,
		XV_Y, 56,
		PANEL_LABEL_STRING, "(use the term window tool to examine directories)",
		PANEL_LABEL_BOLD, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `load_but' in the specified instance.
 */
Xv_opaque
load_choser_load_but_create(ip, owner)
	load_choser_objects	*ip;
	Xv_opaque	owner;
{
	extern void		load_choser_open();
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_BUTTON,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 624,
		XV_Y, 80,
		PANEL_LABEL_STRING, "Load",
		PANEL_NOTIFY_PROC, load_choser_open,
		NULL);
	return obj;
}

save_choser_objects *
save_choser_objects_initialize(ip, owner)
	save_choser_objects	*ip;
	Xv_opaque	owner;
{
	if (!ip && !(ip = (save_choser_objects *) calloc(1, sizeof (save_choser_objects))))
		return (save_choser_objects *) NULL;
	if (!ip->popup)
		ip->popup = save_choser_popup_create(ip, owner);
	if (!ip->controls)
		ip->controls = save_choser_controls_create(ip, ip->popup);
	if (!ip->directory)
		ip->directory = save_choser_directory_create(ip, ip->controls);
	if (!ip->file)
		ip->file = save_choser_file_create(ip, ip->controls);
	if (!ip->message1)
		ip->message1 = save_choser_message1_create(ip, ip->controls);
	if (!ip->save_but)
		ip->save_but = save_choser_save_but_create(ip, ip->controls);
	return ip;
}

/*
 * Create object `popup' in the specified instance.
 */
Xv_opaque
save_choser_popup_create(ip, owner)
	save_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, FRAME_CMD,
		XV_KEY_DATA, INSTANCE, ip,
		XV_WIDTH, 799,
		XV_HEIGHT, 112,
		XV_LABEL, "Save file",
		FRAME_SHOW_FOOTER, TRUE,
		FRAME_SHOW_RESIZE_CORNER, TRUE,
		FRAME_CMD_PUSHPIN_IN, FALSE,
		NULL);
	xv_set(xv_get(obj, FRAME_CMD_PANEL), WIN_SHOW, FALSE, NULL);
	return obj;
}

/*
 * Create object `controls' in the specified instance.
 */
Xv_opaque
save_choser_controls_create(ip, owner)
	save_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 0,
		XV_Y, 0,
		XV_WIDTH, WIN_EXTEND_TO_EDGE,
		XV_HEIGHT, WIN_EXTEND_TO_EDGE,
		WIN_BORDER, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `directory' in the specified instance.
 */
Xv_opaque
save_choser_directory_create(ip, owner)
	save_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 10,
		PANEL_VALUE_DISPLAY_LENGTH, 60,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "Directory:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `file' in the specified instance.
 */
Xv_opaque
save_choser_file_create(ip, owner)
	save_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 32,
		XV_Y, 32,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "Name:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `message1' in the specified instance.
 */
Xv_opaque
save_choser_message1_create(ip, owner)
	save_choser_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_MESSAGE,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 16,
		XV_Y, 56,
		PANEL_LABEL_STRING, "(use the term window tool to examine directories)",
		PANEL_LABEL_BOLD, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `save_but' in the specified instance.
 */
Xv_opaque
save_choser_save_but_create(ip, owner)
	save_choser_objects	*ip;
	Xv_opaque	owner;
{
	extern void		save_choser_open();
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_BUTTON,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 24,
		XV_Y, 80,
		PANEL_LABEL_STRING, "Save",
		PANEL_NOTIFY_PROC, save_choser_open,
		NULL);
	return obj;
}


char           *
save_dir_get()
{
	return (char *) xv_get(Save_choser->directory, PANEL_VALUE);
}

char           *
load_dir_get()
{
	return (char *) xv_get(Load_choser->directory, PANEL_VALUE);
}

void
load_dir_set(name)
	char           *name;
{
	xv_set(Load_choser->directory, PANEL_VALUE, name, 0);
}

void
save_dir_set(name)
	char           *name;
{
	xv_set(Save_choser->directory, PANEL_VALUE, name, 0);
}

void
SAC_dir_set(name)
	char           *name;
{
	xv_set(Save_SAC->directory, PANEL_VALUE, name, 0);
}
 
char           *
save_file_get()
{
	return (char *) xv_get(Save_choser->file, PANEL_VALUE);
}

char           *
load_file_get()
{
	return (char *) xv_get(Load_choser->file, PANEL_VALUE);
}

void
SAC_file_set(name)
	char           *name;
{
	xv_set(Save_SAC->file, PANEL_VALUE, name, 0);
}

void
save_file_set(name)
	char           *name;
{
	xv_set(Save_choser->file, PANEL_VALUE, name, 0);
}

void
load_file_set(name)
	char           *name;
{
	xv_set(Load_choser->file, PANEL_VALUE, name, 0);
}

void
load_choser_open(item, event)
	Panel_item      item;
	Event          *event;
{
	(void) sprintf(loadpath, "%s/%s", load_dir_get(), load_file_get());
	nxscan_file_load(loadpath);
}

void
save_SAC_open(item, event)
	Panel_item      item;
	Event          *event;
{
	(void) sprintf(savepath, "%s/%s", 
	     xv_get(Save_SAC->directory, PANEL_VALUE),
	     xv_get(Save_SAC->file, PANEL_VALUE)   );
	nxscan_file_save(savepath);
}

void
save_choser_open(item, event)
	Panel_item      item;
	Event          *event;
{
	(void) sprintf(savepath, "%s/%s", save_dir_get(), save_file_get());
	nxscan_file_save(savepath);
}

save_SAC_objects *
save_SAC_objects_initialize(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	if (!ip && !(ip = (save_SAC_objects *) calloc(1, sizeof (save_SAC_objects))))
		return (save_SAC_objects *) NULL;
	if (!ip->popup)
		ip->popup = save_SAC_popup_create(ip, owner);
	if (!ip->controls)
		ip->controls = save_SAC_controls_create(ip, ip->popup);
	if (!ip->directory)
		ip->directory = save_SAC_directory_create(ip, ip->controls);
	if (!ip->file)
		ip->file = save_SAC_file_create(ip, ip->controls);
	if (!ip->message1)
		ip->message1 = save_SAC_message1_create(ip, ip->controls);
	if (!ip->save_but)
		ip->save_but = save_SAC_save_but_create(ip, ip->controls);
	if (!ip->start_but)
		ip->start_but = save_SAC_start_but_create(ip, ip->controls);
	if (!ip->stop_but)
		ip->stop_but = save_SAC_stop_but_create(ip, ip->controls);
	if (!ip->y_stop_but)
		ip->y_stop_but = save_SAC_y_stop_but_create(ip, ip->controls);
	if (!ip->y_start_but)
		ip->y_start_but = save_SAC_y_start_but_create(ip, ip->controls);
	if (!ip->mess3)
		ip->mess3 = save_SAC_mess3_create(ip, ip->controls);
	if (!ip->mess4)
		ip->mess4 = save_SAC_mess4_create(ip, ip->controls);
	if (!ip->mess5)
		ip->mess5 = save_SAC_mess5_create(ip, ip->controls);
	if (!ip->message2)
		ip->message2 = save_SAC_message2_create(ip, ip->controls);
	if (!ip->kstnm)
		ip->kstnm = save_SAC_kstnm_create(ip, ip->controls);
	if (!ip->B)
		ip->B = save_SAC_B_create(ip, ip->controls);
	if (!ip->delta)
		ip->delta = save_SAC_delta_create(ip, ip->controls);
	if (!ip->nzyear)
		ip->nzyear = save_SAC_nzyear_create(ip, ip->controls);
	if (!ip->nzday)
		ip->nzday = save_SAC_nzday_create(ip, ip->controls);
	if (!ip->nzhour)
		ip->nzhour = save_SAC_nzhour_create(ip, ip->controls);
	if (!ip->nzmin)
		ip->nzmin = save_SAC_nzmin_create(ip, ip->controls);
	if (!ip->nzsec)
		ip->nzsec = save_SAC_nzsec_create(ip, ip->controls);
	if (!ip->nzmsec)
		ip->nzmsec = save_SAC_nzmsec_create(ip, ip->controls);
	if (!ip->pix_dif)
		ip->pix_dif = save_SAC_pix_dif_create(ip, ip->controls);
	if (!ip->time_dif)
		ip->time_dif = save_SAC_time_dif_create(ip, ip->controls);
	if (!ip->comp_but)
		ip->comp_but = save_SAC_comp_but_create(ip, ip->controls);
	if (!ip->E)
		ip->E = save_SAC_E_create(ip, ip->controls);
	if (!ip->npts)
		ip->npts = save_SAC_npts_create(ip, ip->controls);
	if (!ip->nz_but)
		ip->nz_but = save_SAC_nz_but_create(ip, ip->controls);
	return ip;
}

/*
 * Create object `popup' in the specified instance.
 */
Xv_opaque
save_SAC_popup_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, FRAME_CMD,
		XV_KEY_DATA, INSTANCE, ip,
		XV_WIDTH, 800,
		XV_HEIGHT, 315,
		XV_LABEL, "Save SAC file",
		FRAME_SHOW_FOOTER, TRUE,
		FRAME_SHOW_RESIZE_CORNER, TRUE,
		FRAME_CMD_PUSHPIN_IN, TRUE,
		NULL);
	xv_set(xv_get(obj, FRAME_CMD_PANEL), WIN_SHOW, FALSE, NULL);
	return obj;
}

/*
 * Create object `controls' in the specified instance.
 */
Xv_opaque
save_SAC_controls_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 0,
		XV_Y, 0,
		XV_WIDTH, WIN_EXTEND_TO_EDGE,
		XV_HEIGHT, WIN_EXTEND_TO_EDGE,
		WIN_BORDER, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `directory' in the specified instance.
 */
Xv_opaque
save_SAC_directory_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 210,
		PANEL_VALUE_DISPLAY_LENGTH, 60,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "Directory:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `pix_dif' in the specified instance.
 */
Xv_opaque
save_SAC_pix_dif_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 110,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "time diff. in pixels:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, TRUE,
		NULL);
	return obj;
}

/*
 * Create object `E' in the specified instance.
 */
Xv_opaque
save_SAC_E_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 240,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "E:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, TRUE,
		NULL);
	return obj;
}

/*
 * Create object `npts' in the specified instance.
 */
Xv_opaque
save_SAC_npts_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 260,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "npts:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, TRUE,
		NULL);
	return obj;
}

/*
 * Create object `time_dif' in the specified instance.
 */
Xv_opaque
save_SAC_time_dif_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 130,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "time diff. in secs  :",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `kstnm' in the specified instance.
 */
Xv_opaque
save_SAC_kstnm_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 32,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "KSTNM:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `nzyear' in the specified instance.
 */
Xv_opaque
save_SAC_nzyear_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 98,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "nzyear:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `B' in the specified instance.
 */
Xv_opaque
save_SAC_B_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 54,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "B (float):",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `nzmsec' in the specified instance.
 */
Xv_opaque
save_SAC_nzmsec_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 208,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "nzmsec:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `nzsec' in the specified instance.
 */
Xv_opaque
save_SAC_nzsec_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 186,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "nzsec:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `nzmin' in the specified instance.
 */
Xv_opaque
save_SAC_nzmin_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 164,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "nzmin:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `nzday' in the specified instance.
 */
Xv_opaque
save_SAC_nzday_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 120,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "nzday:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `nzhour' in the specified instance.
 */
Xv_opaque
save_SAC_nzhour_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 142,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "nzhour:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `delta' in the specified instance.
 */
Xv_opaque
save_SAC_delta_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 76,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "delta:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `file' in the specified instance.
 */
Xv_opaque
save_SAC_file_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_TEXT,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 232,
		PANEL_VALUE_DISPLAY_LENGTH, 30,
		PANEL_VALUE_STORED_LENGTH, 1024,
		PANEL_LABEL_STRING, "Name:",
		PANEL_LAYOUT, PANEL_HORIZONTAL,
		PANEL_VALUE_UNDERLINED, FALSE,
		PANEL_READ_ONLY, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `message1' in the specified instance.
 */
Xv_opaque
save_SAC_message1_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_MESSAGE,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 254,
		PANEL_LABEL_STRING, "(use the term window tool to examine directories)",
		PANEL_LABEL_BOLD, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `message2' in the specified instance.
 */
Xv_opaque
save_SAC_message2_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_MESSAGE,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 10,
		XV_Y, 10,
		PANEL_LABEL_STRING, "SAC header data",
		PANEL_LABEL_BOLD, TRUE,
		NULL);
	return obj;
}

/*
 * Create object `mess3' in the specified instance.
 */
Xv_opaque
save_SAC_mess3_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_MESSAGE,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 420,
		XV_Y, 10,
		PANEL_LABEL_STRING, "TIMING",
		PANEL_LABEL_BOLD, TRUE,
		NULL);
	return obj;
}

/*
 * Create object `mess4' in the specified instance.
 */
Xv_opaque
save_SAC_mess4_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_MESSAGE,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 40,
		PANEL_LABEL_STRING, "Press <below left> and select a point",
		PANEL_LABEL_BOLD, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `mess5' in the specified instance.
 */
Xv_opaque
save_SAC_mess5_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_MESSAGE,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 90,
		PANEL_LABEL_STRING, "Press <above right>  and select a point",
		PANEL_LABEL_BOLD, FALSE,
		NULL);
	return obj;
}

/*
 * Create object `save_but' in the specified instance.
 */
Xv_opaque
save_SAC_save_but_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	extern void		save_SAC_open();
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_BUTTON,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 580,
		XV_Y, 290,
		PANEL_LABEL_STRING, "Save",
		PANEL_NOTIFY_PROC, save_SAC_open,
		NULL);
	return obj;
}

/*
 * Create object `comp_but' in the specified instance.
 */
Xv_opaque
save_SAC_comp_but_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	extern void		SAC_compute();
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_BUTTON,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 290,
		PANEL_LABEL_STRING, "Compute",
		PANEL_NOTIFY_PROC, SAC_compute,
		NULL);
	return obj;
}

/*
 * Create object `nz_but' in the specified instance.
 */
Xv_opaque
save_SAC_nz_but_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	extern void		SAC_nz_start();
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_BUTTON,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 150,
		PANEL_LABEL_STRING, "Select nztime=0",
		PANEL_NOTIFY_PROC, SAC_nz_start,
		NULL);
	return obj;
}
/*
 * Create object `start_but' in the specified instance.
 */
Xv_opaque
save_SAC_start_but_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	extern void		SAC_time_start();
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_BUTTON,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 60,
		PANEL_LABEL_STRING, "Time base, 1st point",
		PANEL_NOTIFY_PROC, SAC_time_start,
		NULL);
	return obj;
}

/*
 * Create object `stop_but' in the specified instance.
 */
Xv_opaque
save_SAC_stop_but_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	extern void		SAC_time_stop();
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_BUTTON,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 550,
		XV_Y, 60,
		PANEL_LABEL_STRING, "Time base, 2nd point",
		PANEL_NOTIFY_PROC, SAC_time_stop,
		NULL);
	return obj;
}

/*
 * Create object `y_stop_but' in the specified instance.
 */
Xv_opaque
save_SAC_y_stop_but_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	extern void		SAC_y_stop();
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_BUTTON,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 600,
		XV_Y, 180,
		PANEL_LABEL_STRING, "Baseline, 2nd point",
		PANEL_NOTIFY_PROC, SAC_y_stop,
		NULL);
	return obj;
}

/*
 * Create object `y_start_but' in the specified instance.
 */
Xv_opaque
save_SAC_y_start_but_create(ip, owner)
	save_SAC_objects	*ip;
	Xv_opaque	owner;
{
	extern void		SAC_y_start();
	Xv_opaque	obj;
	
	obj = xv_create(owner, PANEL_BUTTON,
		XV_KEY_DATA, INSTANCE, ip,
		XV_X, 400,
		XV_Y, 180,
		PANEL_LABEL_STRING, "Select Baseline, 1st point",
		PANEL_NOTIFY_PROC, SAC_y_start,
		NULL);
	return obj;
}
